# crawl_wx

Download content from [wechat public content admin](https://mp.weixin.qq.com/cgi-bin/home).

## Install Requirement

- python >= 3.7

## Install

```shell script
pip install crawl_wx
```

## Usage

1. Login https://mp.weixin.qq.com/cgi-bin/home
2. Navigate to #已群发消息#
3. Open chrome developer tool
4. Copy curl request, ![picture](./images/curl.png)
5. Save the copied to a file.
6. run the command
```shell script
crawlwx --curl_file /path/to/curl_file --output /path/to/save
```
